@@ -74,10 +74,13 @@ def print_country_help(self, opt, value, parser):
         c = pycountry.countries.lookup(v)
         if not k in country_ids[c.alpha_2]:
             country_ids[c.alpha_2].append(k)
-    ids = country_ids.values()
+    ids = list(country_ids.values())
     ids.sort()
     print('Known country codes and country names for use with <country>:\n')
-    print(('\n'.join([ '  '+'  -  '.join(v) for v in ids])).encode('utf-8'))
+    if six.PY3:
+        print(('\n'.join([ '  '+'  -  '.join(v) for v in ids])))
+    else:
+        print(('\n'.join([ '  '+'  -  '.join(v) for v in ids])).encode('utf-8'))
     sys.exit()
 
 def get_pdf_help(missing_libs=""):
@@ -235,7 +238,7 @@ def main():
     formatoptions = optparse.OptionGroup(optionparser, 'Generic Format Options')
     formatoptions.add_option('--v3', dest='legacy', action='store_false',
                            help='with --text and --html: use the v3 formatter, rather than the legacy one.')
-    formatoptions.add_option('--legacy', default=True, action='store_true',
+    formatoptions.add_option('--legacy', '--v2', default=True, action='store_true',
                            help='with --text and --html: use the legacy text formatter, rather than the v3 one.')
     formatoptions.add_option('--id-is-work-in-progress', default=True, action='store_true',
                            help='in references, refer to Internet-Drafts as "Work in Progress".')
